==> obsws_cli-0.16.0.tar.gz: obsws_cli-0.16.0/obsws_cli/app.py <==
"""Command line interface for the OBS WebSocket API."""

from typing import Annotated

import obsws_python as obsws
import typer
from rich.console import Console

from obsws_cli.__about__ import __version__ as obsws_cli_version

from . import (
    filter,
    group,
    hotkey,
    input,
    profile,
    projector,
    record,
    replaybuffer,
    scene,
    scenecollection,
    sceneitem,
    screenshot,
    settings,
    stream,
    studiomode,
    virtualcam,
)
from .alias import AliasGroup

app = typer.Typer(cls=AliasGroup)
for module in (
    filter,
    group,
    hotkey,
    input,
    projector,
    profile,
    record,
    replaybuffer,
    scene,
    scenecollection,
    sceneitem,
    screenshot,
    stream,
    studiomode,
    virtualcam,
):
    app.add_typer(module.app, name=module.__name__.split('.')[-1])

out_console = Console()
err_console = Console(stderr=True)


def version_callback(value: bool):
    """Show the version of the CLI."""
    if value:
        out_console.print(f'obsws-cli version: {obsws_cli_version}')
        raise typer.Exit()


@app.callback()
def main(
    ctx: typer.Context,
    host: Annotated[
        str,
        typer.Option(
            '--host',
            '-H',
            envvar='OBS_HOST',
            help='WebSocket host',
            show_default='localhost',
        ),
    ] = settings.get('OBS_HOST'),
    port: Annotated[
        int,
        typer.Option(
            '--port', '-P', envvar='OBS_PORT', help='WebSocket port', show_default=4455
        ),
    ] = settings.get('OBS_PORT'),
    password: Annotated[
        str,
        typer.Option(
            '--password',
            '-p',
            envvar='OBS_PASSWORD',
            help='WebSocket password',
            show_default='',
        ),
    ] = settings.get('OBS_PASSWORD'),
    timeout: Annotated[
        int,
        typer.Option(
            '--timeout',
            '-T',
            envvar='OBS_TIMEOUT',
            help='WebSocket timeout',
            show_default=5,
        ),
    ] = settings.get('OBS_TIMEOUT'),
    version: Annotated[
        bool,
        typer.Option(
            '--version',
            '-v',
            is_eager=True,
            help='Show the CLI version and exit',
            show_default=False,
            callback=version_callback,
        ),
    ] = False,
):
    """obsws_cli is a command line interface for the OBS WebSocket API."""
    ctx.obj = ctx.with_resource(obsws.ReqClient(**ctx.params))


@app.command()
def obs_version(ctx: typer.Context):
    """Get the OBS Client and WebSocket versions."""
    resp = ctx.obj.get_version()
    out_console.print(
        f'OBS Client version: {resp.obs_version} with WebSocket version: {resp.obs_web_socket_version}'
    )

==> obsws_cli-0.17.0.tar.gz: obsws_cli-0.17.0/obsws_cli/app.py <==
"""Command line interface for the OBS WebSocket API."""

import importlib
import logging
from typing import Annotated

import obsws_python as obsws
import typer
from rich.console import Console

from obsws_cli.__about__ import __version__ as obsws_cli_version

from . import settings
from .alias import AliasGroup

app = typer.Typer(cls=AliasGroup)
for sub_typer in (
    'filter',
    'group',
    'hotkey',
    'input',
    'profile',
    'projector',
    'record',
    'replaybuffer',
    'scene',
    'scenecollection',
    'sceneitem',
    'screenshot',
    'stream',
    'studiomode',
    'virtualcam',
):
    module = importlib.import_module(f'.{sub_typer}', package=__package__)
    app.add_typer(module.app, name=sub_typer)

out_console = Console()
err_console = Console(stderr=True, style='bold red')


def version_callback(value: bool):
    """Show the version of the CLI."""
    if value:
        out_console.print(f'obsws-cli version: {obsws_cli_version}')
        raise typer.Exit()


def setup_logging(debug: bool):
    """Set up logging for the application."""
    log_level = logging.DEBUG if debug else logging.CRITICAL
    logging.basicConfig(
        level=log_level,
        format='%(asctime)s - %(name)s - %(levelname)s - %(message)s',
    )


@app.callback()
def main(
    ctx: typer.Context,
    host: Annotated[
        str,
        typer.Option(
            '--host',
            '-H',
            envvar='OBS_HOST',
            help='WebSocket host',
            show_default='localhost',
        ),
    ] = settings.get('host'),
    port: Annotated[
        int,
        typer.Option(
            '--port',
            '-P',
            envvar='OBS_PORT',
            help='WebSocket port',
            show_default=4455,
        ),
    ] = settings.get('port'),
    password: Annotated[
        str,
        typer.Option(
            '--password',
            '-p',
            envvar='OBS_PASSWORD',
            help='WebSocket password',
            show_default=False,
        ),
    ] = settings.get('password'),
    timeout: Annotated[
        int,
        typer.Option(
            '--timeout',
            '-T',
            envvar='OBS_TIMEOUT',
            help='WebSocket timeout',
            show_default=5,
        ),
    ] = settings.get('timeout'),
    version: Annotated[
        bool,
        typer.Option(
            '--version',
            '-v',
            is_eager=True,
            help='Show the CLI version and exit',
            show_default=False,
            callback=version_callback,
        ),
    ] = False,
    debug: Annotated[
        bool,
        typer.Option(
            '--debug',
            '-d',
            envvar='OBS_DEBUG',
            is_eager=True,
            help='Enable debug logging',
            show_default=False,
            callback=setup_logging,
            hidden=True,
        ),
    ] = settings.get('debug'),
):
    """obsws_cli is a command line interface for the OBS WebSocket API."""
    ctx.obj = ctx.with_resource(obsws.ReqClient(**ctx.params))


@app.command()
def obs_version(ctx: typer.Context):
    """Get the OBS Client and WebSocket versions."""
    resp = ctx.obj.get_version()
    out_console.print(
        f'OBS Client version: {resp.obs_version} with WebSocket version: {resp.obs_web_socket_version}'
    )
